@@ -6,12 +6,9 @@
 #' @param year Year of the data. Defaults to 2010
 #' @param code_state The two-digit code of a state or a two-letter uppercase
 #' abbreviation (e.g. 33 or "RJ"). If `code_state="all"`, all states will be loaded.
-#' @param simplified Logic `FALSE` or `TRUE`, indicating whether the function
-#' returns the data set with 'original' resolution or a data set with 'simplified'
-#' borders. Defaults to `TRUE`. For spatial analysis and statistics users should
-#' set `simplified = FALSE`. Borders have been simplified by removing vertices of
-#' borders using `st_simplify{sf}` preserving topology with a `dTolerance` of 100.
-#' @param showProgress Logical. Defaults to `TRUE` display progress bar
+#' @template simplified
+#' @template showProgress
+#'
 #'
 #' @return An `"sf" "data.frame"` object
 #'
@@ -32,6 +29,9 @@ read_state <- function(code_state="all", year=2010, simplified=TRUE, showProgres
   # Get metadata with data url addresses
   temp_meta <- select_metadata(geography="state", year=year, simplified=simplified)
 
+  # check if download failed
+  if (is.null(temp_meta)) { return(invisible(NULL)) }
+
 
 # BLOCK 2.1 From 1872 to 1991  ----------------------------
   x <- year
@@ -39,14 +39,14 @@ read_state <- function(code_state="all", year=2010, simplified=TRUE, showProgres
 if( x < 1992){
 
 #   if( !(substr(x = code_state, 1, 2) %in% temp_meta$code) &
-#       !(substr(x = code_state, 1, 2) %in% temp_meta$code_abrev) &
+#       !(substr(x = code_state, 1, 2) %in% temp_meta$code_abbrev) &
 #       !(substr(x = code_state, 1, 3) %in% "all")) {
 #       stop("Error: Invalid Value to argument code_state.")
 #       }
 
   if(is.null(code_state)){ stop("Value to argument 'code_state' cannot be NULL")}
 
-  if(code_state=="all"){ message("Loading data for the whole country\n")
+  if(code_state=="all"){
 
     # list paths of files to download
     file_url <- as.character(temp_meta$download_path)
@@ -75,7 +75,7 @@ if( x < 1992){
   # Verify code_state input
 
   # if code_state=="all", read the entire country
-    if(code_state=="all"){ message("Loading data for the whole country\n")
+    if(code_state=="all"){
 
       # list paths of files to download
       file_url <- as.character(temp_meta$download_path)
@@ -86,14 +86,14 @@ if( x < 1992){
 
     }
 
-  if( !(substr(x = code_state, 1, 2) %in% temp_meta$code) & !(substr(x = code_state, 1, 2) %in% temp_meta$code_abrev)){
+  if (!(substr(x = code_state, 1, 2) %in% temp_meta$code) & !(substr(x = code_state, 1, 2) %in% temp_meta$code_abbrev)) {
       stop("Error: Invalid Value to argument code_state.")
 
   } else{
 
     # list paths of files to download
     if (is.numeric(code_state)){ file_url <- as.character(subset(temp_meta, code==substr(code_state, 1, 2))$download_path) }
-    if (is.character(code_state)){ file_url <- as.character(subset(temp_meta, code_abrev==substr(code_state, 1, 2))$download_path) }
+    if (is.character(code_state)){ file_url <- as.character(subset(temp_meta, code_abbrev==substr(code_state, 1, 2))$download_path) }
 
 
     # download gpkg
